@@ -1,4 +1,4 @@
-def acos(x) -> float:
+def acos(x: float) -> float:
     """
     Return the arc cosine (measured in randians) of x.
     """
