@@ -1,4 +1,4 @@
-def acsc(x) -> float:
+def acsc(x:float) -> float:
     """
     Return the arc cosecant (measured in radians) of x.
     """
