@@ -1,4 +1,4 @@
-def asec(x) -> float:
+def asec(x:float) -> float:
     """
     Return the arc secant (measured in radians) of x.
     """
