@@ -1,4 +1,4 @@
-def atan(x) -> float:
+def atan(x: float) -> float:
     """
     Return the arc tangent (measured in radians) of x.
     """
