@@ -26,7 +26,7 @@ def cbrt(x: float | complex) -> float | complex:
     while True:
         f = y**3-x
         if abs(f) < 1e-12:
-            return y
+            return float(y)
         f_prime = 3*y**2
         if f_prime == 0:
             y += 1
