@@ -1,4 +1,6 @@
 e = 2.718281828459045090795598298427648842334747314453125
 pi = 3.141592653589793115997963468544185161590576171875
 phi = (1 + 5**.5) / 2
-gamma = 0.57721566490153286060651209008240243104215933593992
\ No newline at end of file
+gamma = 0.57721566490153286060651209008240243104215933593992
+tau = 2*pi
+inf = float("inf")
\ No newline at end of file
