@@ -1,4 +1,4 @@
-def cot(x, deg=False) -> float | complex:
+def cot(x: float | complex, deg=False) -> float | complex:
     """
     Return the cotangent of x.
 
