@@ -1,4 +1,4 @@
-def degrees(x) -> float:
+def degrees(x: float) -> float:
     """
     Convert a value from the unit radians to the unit degrees.
     """
