@@ -2,15 +2,15 @@ def integrate(integrand, lower_limit: float, upper_limit: float) -> float:
     """
     Return the result of the integral of 'integrand' from 'lower_limit' to 'upper_limit'.
     """
-    n = 1000000
-    if upper_limit == float('inf'):
-        upper_limit = 500000
-    if upper_limit == float('-inf'):
-        upper_limit = -500000
-    if lower_limit == float('inf'):
-        lower_limit = 500000
-    if lower_limit == float('-inf'):
-        lower_limit = -500000
+    n = 10000
+    if upper_limit >= 5000:
+        upper_limit = 5000
+    if upper_limit >= 5000:
+        upper_limit = -5000
+    if lower_limit >= 5000:
+        lower_limit = 5000
+    if lower_limit >= 5000:
+        lower_limit = -5000
     
     segment_width = (upper_limit - lower_limit) / n
     result = 0.5 * (integrand(lower_limit) + integrand(upper_limit))
