@@ -1,4 +1,4 @@
-def log(x, base=10) -> float | complex:
+def log(x: float, base=10) -> float | complex:
     """
     Return the logarithm of x in 'base'.
 
