@@ -9,6 +9,6 @@ def sin(x: float | complex, deg=False) -> float | complex:
         x = pi*(x/180)
     if type(x) is not complex:
         return ((e**(1j*x)-e**(1j*-x))/2j).real
-    if ((e**(1j*x)-e**(1j*-x))/2j).imag < 1e-6:
+    if abs(((e**(1j*x)-e**(1j*-x))/2j).imag) < 1e-6:
         return ((e**(1j*x)-e**(1j*-x))/2j).real
     return (e**(1j*x)-e**(1j*-x))/2j
\ No newline at end of file
